@@ -1,18 +1,20 @@
 # -*- coding: utf-8 -*-
 
 # daemon/pidlockfile.py
-# Part of python-daemon, an implementation of PEP 3143.
+# Part of ‘python-daemon’, an implementation of PEP 3143.
 #
-# Copyright © 2008–2009 Ben Finney <ben+python@benfinney.id.au>
+# Copyright © 2008–2014 Ben Finney <ben+python@benfinney.id.au>
 #
 # This is free software: you may copy, modify, and/or distribute this work
-# under the terms of the Python Software Foundation License, version 2 or
-# later as published by the Python Software Foundation.
-# No warranty expressed or implied. See the file LICENSE.PSF-2 for details.
+# under the terms of the Apache License, version 2.0 as published by the
+# Apache Software Foundation.
+# No warranty expressed or implied. See the file LICENSE.ASF-2 for details.
 
 """ Lockfile behaviour implemented via Unix PID files.
     """
 
+from __future__ import (absolute_import, unicode_literals)
+
 import os
 import errno
 
@@ -98,7 +100,7 @@ class TimeoutPIDLockFile(PIDLockFile):
         """
 
     def __init__(self, path, acquire_timeout=None, *args, **kwargs):
-        """ Set up the parameters of a DaemonRunnerLock. """
+        """ Set up the parameters of a TimeoutPIDLockFile. """
         self.acquire_timeout = acquire_timeout
         super(TimeoutPIDLockFile, self).__init__(path, *args, **kwargs)
 
@@ -192,3 +194,10 @@ def remove_existing_pidfile(pidfile_path):
             pass
         else:
             raise
+
+
+# Local variables:
+# coding: utf-8
+# mode: python
+# End:
+# vim: fileencoding=utf-8 filetype=python :
