@@ -1,19 +1,21 @@
 # -*- coding: utf-8 -*-
 #
 # test/test_pidlockfile.py
-# Part of python-daemon, an implementation of PEP 3143.
+# Part of ‘python-daemon’, an implementation of PEP 3143.
 #
-# Copyright © 2008–2009 Ben Finney <ben+python@benfinney.id.au>
+# Copyright © 2008–2014 Ben Finney <ben+python@benfinney.id.au>
 #
 # This is free software: you may copy, modify, and/or distribute this work
-# under the terms of the Python Software Foundation License, version 2 or
-# later as published by the Python Software Foundation.
-# No warranty expressed or implied. See the file LICENSE.PSF-2 for details.
+# under the terms of the Apache License, version 2.0 as published by the
+# Apache Software Foundation.
+# No warranty expressed or implied. See the file LICENSE.ASF-2 for details.
 
 """ Unit test for pidlockfile module.
     """
 
-import __builtin__
+from __future__ import unicode_literals
+
+import __builtin__ as builtins
 import os
 from StringIO import StringIO
 import itertools
@@ -39,6 +41,12 @@ class FakeFileDescriptorStringIO(StringIO, object):
     def fileno(self):
         return self._fileno
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        pass
+
 
 class Exception_TestCase(scaffold.Exception_TestCase):
     """ Test cases for module exception classes. """
@@ -68,58 +76,58 @@ def make_pidlockfile_scenarios():
 
     mock_pidfile_empty = FakeFileDescriptorStringIO()
     mock_pidfile_current_pid = FakeFileDescriptorStringIO(
-        "%(mock_current_pid)d\n" % vars())
+            "%(mock_current_pid)d\n" % vars())
     mock_pidfile_other_pid = FakeFileDescriptorStringIO(
-        "%(mock_other_pid)d\n" % vars())
+            "%(mock_other_pid)d\n" % vars())
     mock_pidfile_bogus = FakeFileDescriptorStringIO(
-        "b0gUs")
+            "b0gUs")
 
     scenarios = {
-        'simple': {},
-        'not-exist': {
-            'open_func_name': 'mock_open_nonexist',
-            'os_open_func_name': 'mock_os_open_nonexist',
-            },
-        'not-exist-write-denied': {
-            'open_func_name': 'mock_open_nonexist',
-            'os_open_func_name': 'mock_os_open_nonexist',
-            },
-        'not-exist-write-busy': {
-            'open_func_name': 'mock_open_nonexist',
-            'os_open_func_name': 'mock_os_open_nonexist',
-            },
-        'exist-read-denied': {
-            'open_func_name': 'mock_open_read_denied',
-            'os_open_func_name': 'mock_os_open_read_denied',
-            },
-        'exist-locked-read-denied': {
-            'locking_pid': mock_other_pid,
-            'open_func_name': 'mock_open_read_denied',
-            'os_open_func_name': 'mock_os_open_read_denied',
-            },
-        'exist-empty': {},
-        'exist-invalid': {
-            'pidfile': mock_pidfile_bogus,
-            },
-        'exist-current-pid': {
-            'pidfile': mock_pidfile_current_pid,
-            'pidfile_pid': mock_current_pid,
-            },
-        'exist-current-pid-locked': {
-            'pidfile': mock_pidfile_current_pid,
-            'pidfile_pid': mock_current_pid,
-            'locking_pid': mock_current_pid,
-            },
-        'exist-other-pid': {
-            'pidfile': mock_pidfile_other_pid,
-            'pidfile_pid': mock_other_pid,
-            },
-        'exist-other-pid-locked': {
-            'pidfile': mock_pidfile_other_pid,
-            'pidfile_pid': mock_other_pid,
-            'locking_pid': mock_other_pid,
-            },
-        }
+            'simple': {},
+            'not-exist': {
+                'open_func_name': 'mock_open_nonexist',
+                'os_open_func_name': 'mock_os_open_nonexist',
+                },
+            'not-exist-write-denied': {
+                'open_func_name': 'mock_open_nonexist',
+                'os_open_func_name': 'mock_os_open_nonexist',
+                },
+            'not-exist-write-busy': {
+                'open_func_name': 'mock_open_nonexist',
+                'os_open_func_name': 'mock_os_open_nonexist',
+                },
+            'exist-read-denied': {
+                'open_func_name': 'mock_open_read_denied',
+                'os_open_func_name': 'mock_os_open_read_denied',
+                },
+            'exist-locked-read-denied': {
+                'locking_pid': mock_other_pid,
+                'open_func_name': 'mock_open_read_denied',
+                'os_open_func_name': 'mock_os_open_read_denied',
+                },
+            'exist-empty': {},
+            'exist-invalid': {
+                'pidfile': mock_pidfile_bogus,
+                },
+            'exist-current-pid': {
+                'pidfile': mock_pidfile_current_pid,
+                'pidfile_pid': mock_current_pid,
+                },
+            'exist-current-pid-locked': {
+                'pidfile': mock_pidfile_current_pid,
+                'pidfile_pid': mock_current_pid,
+                'locking_pid': mock_current_pid,
+                },
+            'exist-other-pid': {
+                'pidfile': mock_pidfile_other_pid,
+                'pidfile_pid': mock_other_pid,
+                },
+            'exist-other-pid-locked': {
+                'pidfile': mock_pidfile_other_pid,
+                'pidfile_pid': mock_other_pid,
+                'locking_pid': mock_other_pid,
+                },
+            }
 
     for scenario in scenarios.values():
         scenario['pid'] = mock_current_pid
@@ -154,16 +162,16 @@ def setup_pidfile_fixtures(testcase):
         return value
 
     scaffold.mock(
-        "os.getpid",
-        returns=scenarios['simple']['pid'],
-        tracker=testcase.mock_tracker)
+            "os.getpid",
+            returns=scenarios['simple']['pid'],
+            tracker=testcase.mock_tracker)
 
     def make_mock_open_funcs(testcase):
 
         def mock_open_nonexist(filename, mode, buffering):
             if 'r' in mode:
                 raise IOError(
-                    errno.ENOENT, "No such file %(filename)r" % vars())
+                        errno.ENOENT, "No such file %(filename)r" % vars())
             else:
                 result = testcase.scenario['pidfile']
             return result
@@ -171,7 +179,7 @@ def setup_pidfile_fixtures(testcase):
         def mock_open_read_denied(filename, mode, buffering):
             if 'r' in mode:
                 raise IOError(
-                    errno.EPERM, "Read denied on %(filename)r" % vars())
+                        errno.EPERM, "Read denied on %(filename)r" % vars())
             else:
                 result = testcase.scenario['pidfile']
             return result
@@ -185,7 +193,7 @@ def setup_pidfile_fixtures(testcase):
                 result = testcase.scenario['pidfile'].fileno()
             else:
                 raise OSError(
-                    errno.ENOENT, "No such file %(filename)r" % vars())
+                        errno.ENOENT, "No such file %(filename)r" % vars())
             return result
 
         def mock_os_open_read_denied(filename, flags, mode):
@@ -193,7 +201,7 @@ def setup_pidfile_fixtures(testcase):
                 result = testcase.scenario['pidfile'].fileno()
             else:
                 raise OSError(
-                    errno.EPERM, "Read denied on %(filename)r" % vars())
+                        errno.EPERM, "Read denied on %(filename)r" % vars())
             return result
 
         def mock_os_open_okay(filename, flags, mode):
@@ -201,8 +209,8 @@ def setup_pidfile_fixtures(testcase):
             return result
 
         funcs = dict(
-            (name, obj) for (name, obj) in vars().items()
-            if hasattr(obj, '__call__'))
+                (name, obj) for (name, obj) in vars().items()
+                if hasattr(obj, '__call__'))
 
         return funcs
 
@@ -219,9 +227,9 @@ def setup_pidfile_fixtures(testcase):
         return result
 
     scaffold.mock(
-        "__builtin__.open",
-        returns_func=mock_open,
-        tracker=testcase.mock_tracker)
+            "builtins.open",
+            returns_func=mock_open,
+            tracker=testcase.mock_tracker)
 
     def mock_os_open(filename, flags, mode=None):
         scenario_path = get_scenario_option(testcase, 'path')
@@ -234,13 +242,13 @@ def setup_pidfile_fixtures(testcase):
         return result
 
     scaffold.mock(
-        "os.open",
-        returns_func=mock_os_open,
-        tracker=testcase.mock_tracker)
+            "os.open",
+            returns_func=mock_os_open,
+            tracker=testcase.mock_tracker)
 
     def mock_os_fdopen(fd, mode='r', buffering=None):
         scenario_pidfile = get_scenario_option(
-            testcase, 'pidfile', FakeFileDescriptorStringIO())
+                testcase, 'pidfile', FakeFileDescriptorStringIO())
         if fd == testcase.scenario['pidfile'].fileno():
             result = testcase.scenario['pidfile']
         else:
@@ -248,48 +256,54 @@ def setup_pidfile_fixtures(testcase):
         return result
 
     scaffold.mock(
-        "os.fdopen",
-        returns_func=mock_os_fdopen,
-        tracker=testcase.mock_tracker)
+            "os.fdopen",
+            returns_func=mock_os_fdopen,
+            tracker=testcase.mock_tracker)
 
     testcase.scenario = NotImplemented
 
 
-def setup_lockfile_method_mocks(testcase, class_name):
+def setup_lockfile_method_mocks(testcase, scenario, class_name):
     """ Set up common mock methods for lockfile class. """
 
+    def mock_read_pid():
+        return scenario['pidfile_pid']
     def mock_is_locked():
-        return (testcase.scenario['locking_pid'] is not None)
+        return (scenario['locking_pid'] is not None)
     def mock_i_am_locking():
         return (
-            testcase.scenario['locking_pid'] == testcase.scenario['pid'])
+                scenario['locking_pid'] == scenario['pid'])
     def mock_acquire(timeout=None):
-        if testcase.scenario['locking_pid'] is not None:
+        if scenario['locking_pid'] is not None:
             raise lockfile.AlreadyLocked()
-        testcase.scenario['locking_pid'] = testcase.scenario['pid']
+        scenario['locking_pid'] = scenario['pid']
     def mock_release():
-        if testcase.scenario['locking_pid'] is None:
+        if scenario['locking_pid'] is None:
             raise lockfile.NotLocked()
-        if testcase.scenario['locking_pid'] != testcase.scenario['pid']:
+        if scenario['locking_pid'] != scenario['pid']:
             raise lockfile.NotMyLock()
-        testcase.scenario['locking_pid'] = None
+        scenario['locking_pid'] = None
     def mock_break_lock():
-        testcase.scenario['locking_pid'] = None
+        scenario['locking_pid'] = None
 
     for func_name in [
-        'is_locked', 'i_am_locking',
-        'acquire', 'release', 'break_lock',
-        ]:
+            'read_pid',
+            'is_locked', 'i_am_locking',
+            'acquire', 'release', 'break_lock',
+            ]:
         mock_func = vars()["mock_%(func_name)s" % vars()]
         lockfile_func_name = "%(class_name)s.%(func_name)s" % vars()
         mock_lockfile_func = scaffold.Mock(
-            lockfile_func_name,
-            returns_func=mock_func,
-            tracker=testcase.mock_tracker)
-        scaffold.mock(
-            lockfile_func_name,
-            mock_obj=mock_lockfile_func,
-            tracker=testcase.mock_tracker)
+                lockfile_func_name,
+                returns_func=mock_func,
+                tracker=testcase.mock_tracker)
+        try:
+            scaffold.mock(
+                    lockfile_func_name,
+                    mock_obj=mock_lockfile_func,
+                    tracker=testcase.mock_tracker)
+        except NameError:
+            pass
 
 
 def setup_pidlockfile_fixtures(testcase, scenario_name=None):
@@ -298,11 +312,11 @@ def setup_pidlockfile_fixtures(testcase, scenario_name=None):
     setup_pidfile_fixtures(testcase)
 
     scaffold.mock(
-        "pidlockfile.write_pid_to_pidfile",
-        tracker=testcase.mock_tracker)
+            "pidlockfile.write_pid_to_pidfile",
+            tracker=testcase.mock_tracker)
     scaffold.mock(
-        "pidlockfile.remove_existing_pidfile",
-        tracker=testcase.mock_tracker)
+            "pidlockfile.remove_existing_pidfile",
+            tracker=testcase.mock_tracker)
 
     if scenario_name is not None:
         set_pidlockfile_scenario(testcase, scenario_name, clear_tracker=False)
@@ -311,12 +325,13 @@ def setup_pidlockfile_fixtures(testcase, scenario_name=None):
 def set_pidlockfile_scenario(testcase, scenario_name, clear_tracker=True):
     """ Set up the test case to the specified scenario. """
     testcase.scenario = testcase.pidlockfile_scenarios[scenario_name]
-    setup_lockfile_method_mocks(testcase, "lockfile.LinkFileLock")
+    setup_lockfile_method_mocks(
+            testcase, testcase.scenario, "lockfile.LinkFileLock")
     testcase.pidlockfile_args = dict(
-        path=testcase.scenario['path'],
-        )
+            path=testcase.scenario['path'],
+            )
     testcase.test_instance = pidlockfile.PIDLockFile(
-        **testcase.pidlockfile_args)
+            **testcase.pidlockfile_args)
     if clear_tracker:
         testcase.mock_tracker.clear()
 
@@ -326,12 +341,16 @@ class PIDLockFile_TestCase(scaffold.TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
+        super(PIDLockFile_TestCase, self).setUp()
+
         setup_pidlockfile_fixtures(self, 'exist-other-pid')
 
     def tearDown(self):
         """ Tear down test fixtures. """
         scaffold.mock_restore()
 
+        super(PIDLockFile_TestCase, self).tearDown()
+
     def test_instantiate(self):
         """ New instance of PIDLockFile should be created. """
         instance = self.test_instance
@@ -354,12 +373,16 @@ class PIDLockFile_read_pid_TestCase(scaffold.TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
+        super(PIDLockFile_read_pid_TestCase, self).setUp()
+
         setup_pidlockfile_fixtures(self, 'exist-other-pid')
 
     def tearDown(self):
         """ Tear down test fixtures. """
         scaffold.mock_restore()
 
+        super(PIDLockFile_read_pid_TestCase, self).tearDown()
+
     def test_gets_pid_via_read_pid_from_pidfile(self):
         """ Should get PID via read_pid_from_pidfile. """
         instance = self.test_instance
@@ -374,6 +397,8 @@ class PIDLockFile_acquire_TestCase(scaffold.TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
+        super(PIDLockFile_acquire_TestCase, self).setUp()
+
         setup_pidlockfile_fixtures(self)
         set_pidlockfile_scenario(self, 'not-exist')
 
@@ -381,6 +406,8 @@ class PIDLockFile_acquire_TestCase(scaffold.TestCase):
         """ Tear down test fixtures. """
         scaffold.mock_restore()
 
+        super(PIDLockFile_acquire_TestCase, self).tearDown()
+
     def test_calls_linkfilelock_acquire(self):
         """ Should first call LinkFileLock.acquire method. """
         instance = self.test_instance
@@ -432,12 +459,16 @@ class PIDLockFile_release_TestCase(scaffold.TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
+        super(PIDLockFile_release_TestCase, self).setUp()
+
         setup_pidlockfile_fixtures(self)
 
     def tearDown(self):
         """ Tear down test fixtures. """
         scaffold.mock_restore()
 
+        super(PIDLockFile_release_TestCase, self).tearDown()
+
     def test_does_not_remove_existing_pidfile_if_not_locking(self):
         """ Should not request removal of PID file if not locking. """
         set_pidlockfile_scenario(self, 'exist-empty')
@@ -496,6 +527,8 @@ class PIDLockFile_break_lock_TestCase(scaffold.TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
+        super(PIDLockFile_break_lock_TestCase, self).setUp()
+
         setup_pidlockfile_fixtures(self)
         set_pidlockfile_scenario(self, 'exist-other-pid-locked')
 
@@ -503,6 +536,8 @@ class PIDLockFile_break_lock_TestCase(scaffold.TestCase):
         """ Tear down test fixtures. """
         scaffold.mock_restore()
 
+        super(PIDLockFile_break_lock_TestCase, self).tearDown()
+
     def test_calls_linkfilelock_break_lock(self):
         """ Should first call LinkFileLock.break_lock method. """
         instance = self.test_instance
@@ -530,18 +565,22 @@ class read_pid_from_pidfile_TestCase(scaffold.TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
+        super(read_pid_from_pidfile_TestCase, self).setUp()
+
         setup_pidfile_fixtures(self)
 
     def tearDown(self):
         """ Tear down test fixtures. """
         scaffold.mock_restore()
 
+        super(read_pid_from_pidfile_TestCase, self).tearDown()
+
     def test_opens_specified_filename(self):
         """ Should attempt to open specified pidfile filename. """
         set_pidlockfile_scenario(self, 'exist-other-pid')
         pidfile_path = self.scenario['path']
         expect_mock_output = """\
-            Called __builtin__.open(%(pidfile_path)r, 'r')
+            Called builtins.open(%(pidfile_path)r, u'r')
             """ % vars()
         dummy = pidlockfile.read_pid_from_pidfile(pidfile_path)
         scaffold.mock_restore()
@@ -597,6 +636,8 @@ class remove_existing_pidfile_TestCase(scaffold.TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
+        super(remove_existing_pidfile_TestCase, self).setUp()
+
         setup_pidfile_fixtures(self)
 
         scaffold.mock(
@@ -607,6 +648,8 @@ class remove_existing_pidfile_TestCase(scaffold.TestCase):
         """ Tear down test fixtures. """
         scaffold.mock_restore()
 
+        super(remove_existing_pidfile_TestCase, self).tearDown()
+
     def test_removes_specified_filename(self):
         """ Should attempt to remove specified PID file filename. """
         set_pidlockfile_scenario(self, 'exist-current-pid')
@@ -648,6 +691,8 @@ class write_pid_to_pidfile_TestCase(scaffold.TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
+        super(write_pid_to_pidfile_TestCase, self).setUp()
+
         setup_pidfile_fixtures(self)
         set_pidlockfile_scenario(self, 'not-exist')
 
@@ -655,6 +700,8 @@ class write_pid_to_pidfile_TestCase(scaffold.TestCase):
         """ Tear down test fixtures. """
         scaffold.mock_restore()
 
+        super(write_pid_to_pidfile_TestCase, self).tearDown()
+
     def test_opens_specified_filename(self):
         """ Should attempt to open specified PID file filename. """
         pidfile_path = self.scenario['path']
@@ -696,3 +743,101 @@ class write_pid_to_pidfile_TestCase(scaffold.TestCase):
         pidlockfile.write_pid_to_pidfile(pidfile_path)
         scaffold.mock_restore()
         self.failUnlessMockCheckerMatch(expect_mock_output)
+
+
+class TimeoutPIDLockFile_TestCase(scaffold.TestCase):
+    """ Test cases for ‘TimeoutPIDLockFile’ class. """
+
+    def setUp(self):
+        """ Set up test fixtures. """
+        super(TimeoutPIDLockFile_TestCase, self).setUp()
+
+        self.mock_tracker = scaffold.MockTracker()
+
+        pidlockfile_scenarios = make_pidlockfile_scenarios()
+        self.pidlockfile_scenario = pidlockfile_scenarios['simple']
+        pidfile_path = self.pidlockfile_scenario['path']
+
+        scaffold.mock(
+                "pidlockfile.PIDLockFile.__init__",
+                tracker=self.mock_tracker)
+        scaffold.mock(
+                "pidlockfile.PIDLockFile.acquire",
+                tracker=self.mock_tracker)
+
+        self.scenario = {
+                'pidfile_path': self.pidlockfile_scenario['path'],
+                'acquire_timeout': object(),
+                }
+
+        self.test_kwargs = dict(
+                path=self.scenario['pidfile_path'],
+                acquire_timeout=self.scenario['acquire_timeout'],
+                )
+        self.test_instance = pidlockfile.TimeoutPIDLockFile(
+                **self.test_kwargs)
+
+    def tearDown(self):
+        """ Tear down test fixtures. """
+        scaffold.mock_restore()
+
+        super(TimeoutPIDLockFile_TestCase, self).tearDown()
+
+    def test_inherits_from_pidlockfile(self):
+        """ Should inherit from PIDLockFile. """
+        instance = self.test_instance
+        self.failUnlessIsInstance(instance, pidlockfile.PIDLockFile)
+
+    def test_init_has_expected_signature(self):
+        """ Should have expected signature for ‘__init__’. """
+        def test_func(self, path, acquire_timeout=None, *args, **kwargs): pass
+        test_func.__name__ = b'__init__'
+        self.failUnlessFunctionSignatureMatch(
+                test_func, 
+                pidlockfile.TimeoutPIDLockFile.__init__)
+
+    def test_has_specified_acquire_timeout(self):
+        """ Should have specified ‘acquire_timeout’ value. """
+        instance = self.test_instance
+        expect_timeout = self.test_kwargs['acquire_timeout']
+        self.failUnlessEqual(expect_timeout, instance.acquire_timeout)
+
+    def test_calls_superclass_init(self):
+        """ Should call the superclass ‘__init__’. """
+        expect_path = self.test_kwargs['path']
+        expect_mock_output = """\
+                Called pidlockfile.PIDLockFile.__init__(
+                    %(expect_path)r)
+                """ % vars()
+        self.failUnlessMockCheckerMatch(expect_mock_output)
+
+    def test_acquire_uses_specified_timeout(self):
+        """ Should call the superclass ‘acquire’ with specified timeout. """
+        instance = self.test_instance
+        test_timeout = object()
+        expect_timeout = test_timeout
+        self.mock_tracker.clear()
+        expect_mock_output = """\
+                Called pidlockfile.PIDLockFile.acquire(%(expect_timeout)r)
+                """ % vars()
+        instance.acquire(test_timeout)
+        self.failUnlessMockCheckerMatch(expect_mock_output)
+
+    def test_acquire_uses_stored_timeout_by_default(self):
+        """ Should call superclass ‘acquire’ with stored timeout by default. """
+        instance = self.test_instance
+        test_timeout = self.test_kwargs['acquire_timeout']
+        expect_timeout = test_timeout
+        self.mock_tracker.clear()
+        expect_mock_output = """\
+                Called pidlockfile.PIDLockFile.acquire(%(expect_timeout)r)
+                """ % vars()
+        instance.acquire()
+        self.failUnlessMockCheckerMatch(expect_mock_output)
+
+
+# Local variables:
+# coding: utf-8
+# mode: python
+# End:
+# vim: fileencoding=utf-8 filetype=python :
